<?php

/**
 * @version     1.0.0
 * @package     com_sp_orders
 * @copyright   http://Atoll-it.ru Copyright (C) 2013. All rights reserved.
 * @license     Proprietary software
 * @author      Atolloc <develop@atoll-it.ru> - http://atoll-it.ru
 */
defined('_JEXEC') or die;

jimport('joomla.application.component.modellist');

/**
 * Methods supporting a list of Sp_orders records.
 */
class Sp_ordersModelFilesorders extends JModelList {

	protected $dates = [];
    /**
     * Constructor.
     *
     * @param    array    An optional associative array of configuration settings.
     * @see        JController
     * @since    1.6
     */
    public function __construct($config = array()) {
        parent::__construct($config);
    }

    /**
     * Method to auto-populate the model state.
     *
     * Note. Calling getState in this method will result in recursion.
     *
     * @since	1.6
     */
    protected function populateState($ordering = null, $direction = null) {

        // Initialise variables.
        $app = JFactory::getApplication();

        // List state information
        $limit = $app->getUserStateFromRequest('global.list.limit', 'limit', $app->getCfg('list_limit'));
        $this->setState('list.limit', $limit);

        $limitstart = JFactory::getApplication()->input->getInt('limitstart', 0);
        $this->setState('list.start', $limitstart);

        
		if(empty($ordering)) {
			$ordering = 'a.ordering';
		}

		$yearInput = $app->input->get('year', date('Y'));
		$year = $yearInput;
		$this->setState('list.year', $year);

        // List state information.
        parent::populateState($ordering, $direction);
    }

    /**
     * Build an SQL query to load the list data.
     *
     * @return	JDatabaseQuery
     * @since	1.6
     */
    protected function getListQuery() {
        // Create a new query object.
        $db = $this->getDbo();
        $query = $db->getQuery(true);

        // Select the required fields from the table.
        $query->select(
                $this->getState(
                        'list.select', 'a.*'
                )
        );

        $query->from('`#__sp_files_orders` AS a');

        
    // Join over the users for the checked out user.
    $query->select('uc.name AS editor');
    $query->join('LEFT', '#__users AS uc ON uc.id=a.checked_out');
    
		// Join over the created by field 'created_by'
		$query->select('created_by.name AS created_by');
		$query->join('LEFT', '#__users AS created_by ON created_by.id = a.created_by');

		$dates = $this->loadDates();
		$this->setState('dates.links', $dates);

		$year = $this->getState('list.year', 'all');

		if (!empty($year) && $year !== 'all') {
			$dateValue = $db->escape($year, true);
			$query->where('YEAR(a.date) = ' . $dateValue);
		}

		$query->order('a.date DESC');


        // Filter by search in title
        $search = $this->getState('filter.search');
        if (!empty($search)) {
            if (stripos($search, 'id:') === 0) {
                $query->where('a.id = ' . (int) substr($search, 3));
            } else {
                $search = $db->Quote('%' . $db->escape($search, true) . '%');
            }
        }

        return $query;
    }

	/**
	 * @return array
	 */
    protected function loadDates() {
    	if (empty($this->dates)) {
			$db = $this->getDbo();
			$qDates = $db->getQuery(true);

			$qDates->select("YEAR(a.date) as year");
			$qDates->from('`#__sp_files_orders` AS a');
			$qDates->where('a.date > 0');
			$qDates->group('YEAR(a.date)');
			$qDates->order('a.date DESC');

			$db->setQuery($qDates);
			$results = $db->loadObjectList();

			foreach ($results as $item) {
				$this->dates[] = $item->year;
			}
		}

		return $this->dates;
	}

	/**
	 *
	 */
	public function getDatesLinks() {
		$output = [];

		foreach($this->loadDates() as $yearVal) {
			$output[] = '<a href="?year='. $yearVal .'">'.$yearVal.'</a>';
		}

		return $output;
	}

    public function getItems() {
        return parent::getItems();
    }

}
